@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.2
-id: yesod-1.4.2-8994ae96a816d1aace7e2b388f9ba84e
-key: yesod_82vSA8z2cdILdixikGgx8t
+id: yesod-1.4.2-d41a6dc060ccf2fb42eddaf13505e374
+key: yesod_BY61wQKIxhkGlJRndtOPt5
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,7 +21,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.2
-hs-libraries: HSyesod-1.4.2-82vSA8z2cdILdixikGgx8t
+hs-libraries: HSyesod-1.4.2-BY61wQKIxhkGlJRndtOPt5
 depends:
     aeson-0.11.0.0-3b69ab8a9952fc7c94fde12b431d717b
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
@@ -46,12 +46,12 @@ depends:
     wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
     wai-extra-3.0.13.1-22d19709bfcccb29f4594bf354c81852
     wai-logger-2.2.4.1-f24597f93ba49a0bbd4e6ed0edc7bef2
-    warp-3.2.1-4bdf427d1f92fd4de5e1e827ed9b1276
+    warp-3.2.3-fdc49a5718602b1caa75db5ed6223617
     yaml-0.8.16-fb65281075453c8e8a8a864f3d81487b
-    yesod-auth-1.4.12-4eb7c4aac3cb78ba477d936342de8969
-    yesod-core-1.4.19-30aa3dec94572d19698f25c55f6fdd4f
-    yesod-form-1.4.6-3eef7a59d19c1396cc78d85b66648731
-    yesod-persistent-1.4.0.3-ca5a75367b988d48b524d0aecd2cb90c
+    yesod-auth-1.4.12-2f12e854d18d69e2d9c6c435df549cd2
+    yesod-core-1.4.19-ac3f1cf7050a843b1fae43913e33aa84
+    yesod-form-1.4.6-0963046a3719ced027a31ebffa00f827
+    yesod-persistent-1.4.0.3-08d92748021fa02d2a68021a320ee7fd
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
